==> apache-artemis-2.33.0-source-release.tar.gz: apache-artemis-2.33.0/artemis-journal/src/main/java/org/apache/activemq/artemis/core/io/buffer/TimedBufferObserver.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.activemq.artemis.core.io.buffer;

import java.util.List;

import io.netty.buffer.ByteBuf;
import org.apache.activemq.artemis.core.io.IOCallback;

public interface TimedBufferObserver {

   /**
    * It flushes {@link ByteBuf#readableBytes()} of {@code buffer} without changing its reader/writer indexes.<br>
    * It just use {@code buffer} temporary: it can be reused by the caller right after this call.
    */
   void flushBuffer(ByteBuf buffer, boolean syncRequested, List<IOCallback> callbacks);

   default void checkSync(boolean syncRequested, List<IOCallback> callbacks) {
   }

   default boolean supportSync() {
      return false;
   }

   /**
    * Return the number of remaining bytes that still fit on the observer (file)
    */
   int getRemainingBytes();

}

==> apache-artemis-2.42.0-source-release.tar.gz: apache-artemis-2.42.0/artemis-journal/src/main/java/org/apache/activemq/artemis/core/io/buffer/TimedBufferObserver.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.activemq.artemis.core.io.buffer;

import java.util.List;

import io.netty.buffer.ByteBuf;
import org.apache.activemq.artemis.core.io.IOCallback;

public interface TimedBufferObserver {

   /**
    * It flushes {@link ByteBuf#readableBytes()} of {@code buffer} without changing its reader/writer indexes.
    * <p>
    * It just use {@code buffer} temporary: it can be reused by the caller right after this call.
    */
   void flushBuffer(ByteBuf buffer, boolean syncRequested, List<IOCallback> callbacks);

   default void checkSync(boolean syncRequested, List<IOCallback> callbacks) {
   }

   default boolean supportSync() {
      return false;
   }

   /**
    * Return the number of remaining bytes that still fit on the observer (file)
    */
   int getRemainingBytes();

}
